@@ -1,4 +1,4 @@
 from typing import Optional
-from .SmarterInterface import SmarterPlugin, SmarterMessage, SmarterSender
+from .smarterInterface import SmarterPlugin, SmarterMessage, SmarterSender
 
 __all__ = ["SmarterPlugin", "SmarterMessage", "SmarterSender", "Optional"]
