@@ -273,10 +273,34 @@ class SmarterSender:
         return data
 
     def write_dataframe_to_lake(self, df, table_name: str) -> None:
+        """
+        Inserts a :class:`pandas.DataFrame` into an table within the current dat lake.
+        Args:
+             :param df: pd.DataFrame
+                Contains row values to insert into `table`
+             :param table_name: str
+                 The name of the table to insert to in the lake.
+         """
         self.__db.write_from_dataframe(df=df, table_name=table_name)
 
     def bulk_insert_to_lake(self, file_name: str, table_name: str, delimiter: str, column_names: List[str],
-                            parameter_indices: List[int], batch_size: int = 1):
+                            parameter_indices: List[int], batch_size: int = 1) -> None:
+        """
+        Runs a single bulk insert statement into the data lake from a CSV FILE.
+        Args:
+             :param file_name: str
+                 The name of the CSV file to read from.
+             :param table_name: str
+                 The name of the table to insert to.
+             :param column_names:list
+                 The name of the columns in the table to insert to.
+             :param parameter_indices:list
+                 The indexes of the columns in the file to insert to.
+             :param delimiter: str
+                 The delimiter to use when reading the file.
+            :param batch_size: int
+                The number of rows to insert per insert statement. Minimum allowed value is 1.
+        """
 
         self.__db.bulk_insert(file_name=file_name,
                               table_name=table_name,
